/*
Copyright (c) Dale Anson, 2004

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice,
  this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
  notice, this list of conditions and the following disclaimer in the
  documentation and/or other materials provided with the distribution.   
  3. The name of the author may not be used to endorse or promote products
  derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package ise.dbconsole;

/**
 * Modification of Command pattern, this allows data to be passed to the
 * command, plus the executed command can return data. Additional modification
 * for DbConsole, some commands take a while to run, so DbConsole can show a
 * "spinner" indicating that the command is running. The <code>showSpinner</code>
 * method lets the individual commands signal whether DbConsole should show the
 * spinner or not. The default is to show the spinner.
 *
 * @version   $Revision: 7 $
 */
public abstract class Command {

    /**
     * Execute the command. A common implementation is to delegate to <code>
     * execute(Object)</code> and pass null.
     *
     * @return   Description of the Returned Value
     */
    public abstract String execute();

    /**
     * Execute the command.
     *
     * @param data  data for the command.
     * @return      Description of the Returned Value
     */
    public abstract String execute(Object data);

    /**
     * Should DbConsole show the spinner?  Most commands can leave this as is,
     * it usually doesn't hurt anything to show the spinner.
     *
     * @return   default is true, subclasses should override to return false if
     *      they process quickly or have special displays that they are
     *      handling.
     */
    public boolean showSpinner() {
        return true;
    }
}

