/*
Copyright (c) Dale Anson, 2004
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
package ise.dbconsole;

import java.io.*;
import java.util.*;
import java.util.prefs.*;
import ise.dbconsole.command.*;

import ise.dbconsole.to.*;
import ise.library.*;
import ise.library.ascii.*;

/**
 * Copyright 2003
 *
 * @version   $Revision: 18 $
 */
public class DbConsoleUtil implements Constants {

    public final static String DBINFO = "dbinfo";

    /**
     * Description of the Method
     *
     * @param dbinfo
     */
    public static void storeDbInfo(DbInfo dbinfo) {
        Preferences dbinfos = Preferences.userNodeForPackage(DbConsole.class).node(DBINFO);
        Preferences new_dbinfo = dbinfos.node(dbinfo.getId());
        new_dbinfo.put("name", dbinfo.getName());
        new_dbinfo.put("url", dbinfo.getUrl());
        new_dbinfo.put("driver", dbinfo.getDriver());
        User user = dbinfo.getUser();
        if (user != null)
            new_dbinfo.put("last_user", user.getUsername());
        try {
            Preferences users = new_dbinfo.node("users");
            users.clear();
            for (Iterator it = dbinfo.getUsers().iterator(); it.hasNext(); ) {
                user = (User) it.next();
                users.put(user.getUsername(), user.getPassword());
            }
        }
        catch (Exception ignored) {     // NOPMD
        }
        try {
            Preferences queries = new_dbinfo.node("queries");
            queries.clear();
            int index = 0;
            for (Iterator it = dbinfo.getSavedQueries().iterator(); it.hasNext(); ) {
                String query = (String) it.next();
                queries.put(String.valueOf(index), query);
                ++index;
            }
        }
        catch (Exception ignored) {     // NOPMD
        }
        try {
            new_dbinfo.flush();
        }
        catch(Exception e) {            // NOPMD
        }
    }

    /**
     * Export the configuration information for a single database setting.
     *
     * @param dbinfo         the DbInfo for the database configuration to
     *      export.
     * @param filename       the name of a file to receive the configuration. If
     *      the file exists, it will be overwritten.
     * @exception Exception  Description of Exception
     */
    public static void exportDbInfo(DbInfo dbinfo, String filename) throws Exception {      // NOPMD
        Preferences dbinfos = Preferences.userNodeForPackage(DbConsole.class).node(DBINFO);
        Preferences node = dbinfos.node(dbinfo.getId());
        FileOutputStream fos = new FileOutputStream(filename);
        node.exportSubtree(fos);
    }

    /**
     * Export the complete configuration for DbConsole.
     *
     * @param filename       the name of a file to receive the configuration. If
     *      the file exists, it will be overwritten.
     * @exception Exception  Description of Exception
     */
    public static void exportConfig(String filename) throws Exception {     // NOPMD
        Preferences node = Preferences.userNodeForPackage(DbConsole.class).node(DBINFO);
        FileOutputStream fos = new FileOutputStream(filename);
        node.exportSubtree(fos);
    }

    public static void importConfig(String filename) throws Exception {     // NOPMD
        Preferences node = Preferences.userNodeForPackage(DbConsole.class).node(DBINFO);
        FileInputStream fis = new FileInputStream(filename);
        node.importPreferences(fis);
    }

    /**
     * Description of the Method
     *
     * @param dbinfo
     */
    public static void removeDbConfig(DbInfo dbinfo) {
        try {
            Preferences dbinfos = Preferences.userNodeForPackage(DbConsole.class).node(DBINFO);
            Preferences to_remove = dbinfos.node(dbinfo.getId());
            to_remove.removeNode();
        }
        catch (Exception e) {
            System.out.println(e.getMessage());
        }
    }

    /**
     * Gets the defaultDbConfiguration attribute of the DbConsoleUtil class
     *
     * @return   The defaultDbConfiguration value
     */
    public static DbInfo getDefaultDbConfiguration() {
        try {
            String id = Preferences.userNodeForPackage(DbConsole.class).get("last_config", null);
            return getDbConfiguration(id);
        }
        catch (Exception e) {
            return null;
        }
    }

    /**
     * Gets the showRowColumn attribute of the DbConsoleUtil class
     *
     * @return   The showRowColumn value
     */
    public static boolean getShowRowColumn() {
        try {
            return Preferences.userNodeForPackage(DbConsole.class).getBoolean(SHOW_ROW_COLUMN, true);
        }
        catch (Exception e) {
            return true;
        }
    }

    /**
     * Sets the showRowColumn attribute of the DbConsoleUtil class
     *
     * @param b  The new showRowColumn value
     */
    public static void setShowRowColumn(boolean b) {
        try {
            Preferences.userNodeForPackage(DbConsole.class).putBoolean(SHOW_ROW_COLUMN, b);
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Sets the default width of the message boxes
     *
     * @param w the width of the box in characters
     */
    public static void setBoxWidth(int w) {
        try {
            Preferences.userNodeForPackage(DbConsole.class).putInt(BOX_WIDTH, w);
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static int getBoxWidth() {
        try {
            return Preferences.userNodeForPackage(DbConsole.class).getInt(BOX_WIDTH, 60);
        }
        catch (Exception e) {
            return 60;
        }
    }

    /**
     * Sets the size of the query history
     *
     * @param s the number of queries to keep
     */
    public static void setQueryHistorySize(int s) {
        try {
            Preferences.userNodeForPackage(DbConsole.class).putInt(QUERY_HISTORY_SIZE, s);
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static int getQueryHistorySize() {
        try {
            return Preferences.userNodeForPackage(DbConsole.class).getInt(QUERY_HISTORY_SIZE, 20);
        }
        catch (Exception e) {
            return 20;
        }
    }

    /**
     * Gets the showColor attribute of the DbConsoleUtil class
     *
     * @return   The showColor value
     */
    public static boolean getShowColor() {
        try {
            return Preferences.userNodeForPackage(DbConsole.class).getBoolean(SHOW_COLOR, true);
        }
        catch (Exception e) {
            return true;
        }
    }

    /**
     * Sets the showColor attribute of the DbConsoleUtil class
     *
     * @param b  The new showColor value
     */
    public static void setShowColor(boolean b) {
        try {
            Preferences.userNodeForPackage(DbConsole.class).putBoolean(SHOW_COLOR, b);
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Gets the color attribute of the DbConsoleUtil class
     *
     * @return   The color value
     */
    public static String getColor() {
        try {
            return Preferences.userNodeForPackage(DbConsole.class).get(COLOR, "cyan");
        }
        catch (Exception e) {
            return "cyan";
        }
    }

    /**
     * Sets the color attribute of the DbConsoleUtil class
     *
     * @param color  The new color value
     */
    public static void setColor(String color) {
        try {
            Preferences.userNodeForPackage(DbConsole.class).put(COLOR, color);
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Sets the defaultDbConfiguration attribute of the DbConsoleUtil class
     *
     * @param dbinfo  The new defaultDbConfiguration value
     */
    public static void setDefaultDbConfiguration(DbInfo dbinfo) {
        if (dbinfo == null)
            return;
        String id = dbinfo.getId();
        if (id == null || id.length() == 0)
            return;
        try {
            Preferences.userNodeForPackage(DbConsole.class).put("last_config", id);
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Gets the dbConfiguration attribute of the DbConsoleUtil class
     *
     * @param dbinfo_id
     * @return           The dbConfiguration value
     */
    public static DbInfo getDbConfiguration(String dbinfo_id) {
        try {
            Preferences settings = Preferences.userNodeForPackage(DbConsole.class).node(DBINFO).node(dbinfo_id);
            DbInfo dbinfo = new DbInfo();
            dbinfo.setId(dbinfo_id);
            dbinfo.setUrl(settings.get("url", ""));
            dbinfo.setName(settings.get("name", ""));
            dbinfo.setDriver(settings.get("driver", ""));
            Preferences users = settings.node("users");
            String[] usernames = users.keys();
            for (int j = 0; j < usernames.length; j++) {
                User user = new User();
                user.setUsername(usernames[j]);
                user.setPassword(users.get(usernames[j], ""));
                dbinfo.addUser(user);
            }
            String last_user = settings.get("last_user", null);
            if (last_user != null) {
                dbinfo.setUser(last_user);
            }
            Preferences queries = settings.node("queries");
            ArrayList rs = new ArrayList();
            String[] keys = queries.keys();
            for (int i = 0; i < keys.length; i++) {
                String query = queries.get(keys[i], "");
                rs.add(query);
            }
            dbinfo.setSavedQueries(rs);
            return dbinfo;
        }
        catch (Exception e) {
            return null;
        }
    }

    /**
     * Gets the dbConfigurations attribute of the DbConsoleUtil class
     *
     * @return   The dbConfigurations value
     */
    public static List getDbConfigurations() {
        try {
            Preferences dbinfos = Preferences.userNodeForPackage(DbConsole.class).node(DBINFO);
            String[] dbinfo_ids = dbinfos.childrenNames();
            if (dbinfo_ids.length == 0) {
                return null;
            }
            else {
                List list = new ArrayList();
                for (int i = 0; i < dbinfo_ids.length; i++) {
                    String dbinfo_id = dbinfo_ids[i];
                    DbInfo dbinfo = getDbConfiguration(dbinfo_id);
                    if (dbinfo != null)
                        list.add(dbinfo);
                }
                Collections.sort(list);
                return list;
            }
        }
        catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * Description of the Method
     *
     * @return   Description of the Returned Value
     */
    public static User createUser() {
        String username;
        User user = new User();
        Input input = new TextInput(DbConsole.prompt + Bundle.BUNDLE.getString("enterUsername") + ":");
        username = input.getInput();
        user.setUsername(username);
        ChangePasswordCommand cpc = new ChangePasswordCommand();
        cpc.execute(user);
        return user;
    }

}

