/*
Copyright (c) Dale Anson, 2004

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.   
   3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package ise.dbconsole;

import java.io.*;

/**
 * TeeWriter, sends output to 2 writers at once.
 *
 * @author    Dale Anson, Sep 2004
 * @version   $Revision: 7 $
 */
public class TeeOutputStream extends OutputStream {
    private OutputStream left;
    private OutputStream right;

    /**
     * Constructor for TeeWriter
     *
     * @param left one side of the tee
     * @param right the other side of the tee
     */
    public TeeOutputStream(OutputStream left, OutputStream right) {
        this.left = left;
        this.right = right;
    }

    /**
     * Close the tee, flushes and closes both sides of the tee.
     *
     * @exception IOException  on any error flushing or closing the tee.
     */
    public void close() throws IOException {
        flush();
        left.close();
        right.close();
    }

    /**
     * Flushes both sides of the tee.
     *
     * @exception IOException  on any error flushing the tee.
     */
    public void flush() throws IOException {
        left.flush();
        right.flush();
    }

    /**
     * Write a character to both sides of the tee.
     *
     * @param c
     * @exception IOException  Description of Exception
     */
    public void write(int c) throws IOException {
        left.write(c);
        right.write(c);
    }

}

