/*
Copyright (c) Dale Anson, 2004

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.   
   3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package ise.dbconsole.command;

import ise.dbconsole.*;
import ise.dbconsole.to.*;
import ise.library.ascii.*;
import java.io.*;
import java.util.*;

/**
 * Export the configuration settings to a file.
 *
 * @author Dale Anson, Sep 2004
 * @version   $Revision: 7 $
 */
public class ExportConfigCommand extends Command {

    public String execute() {
        return execute(null);
    }

    public String execute(Object data) {
        List db_configs = DbConsoleUtil.getDbConfigurations();
        if (db_configs == null || db_configs.size() == 0) {
            db_configs = new ArrayList();
        }
        db_configs.add(Bundle.BUNDLE.getString("all"));
        
        // fetch the user's choice
        ChoiceInput choiceField = new ChoiceInput(db_configs);
        choiceField.setResourceBundle(Bundle.BUNDLE);
        choiceField.setIntro(Bundle.BUNDLE.getString("exportConfig") + ": ");
        Object o = choiceField.getChoice();
        DbInfo dbinfo;
        if (o != ChoiceInput.USER_CANCELLED && !Bundle.BUNDLE.getString("all").equals(o)) {
            dbinfo = (DbInfo) o;
            Input input = new TextInput("Enter filename:");
            String filename = input.getInput();
            if (filename == null || filename.trim().length() == 0)
                return null;
            try {
                DbConsoleUtil.exportDbInfo(dbinfo, filename);
            }
            catch(Exception e) {
                return Bundle.BUNDLE.getString("error") + " " + e.getMessage();
            }
        }
        else if (o == ChoiceInput.USER_CANCELLED) {
            // user selected cancel, so just return without doing anything else
            return null;
        }
        else {
            // user selected all, so get a filename
            Input input = new TextInput("Enter filename:");
            String filename = input.getInput();
            if (filename == null || filename.trim().length() == 0)
                return null;
            try {
                DbConsoleUtil.exportConfig(filename);
            }
            catch(Exception e) {
                return Bundle.BUNDLE.getString("error") + " " + e.getMessage();
            }
        }
        return null;
    }
    
    /**
     * Tell DbConsole to NOT show a spinner.
     *
     * @return   false
     */
    public boolean showSpinner() {
        return false;
    }
    
}

