/*
Copyright (c) Dale Anson, 2004
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
   1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
   3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
package ise.dbconsole.command;

import java.io.*;

import ise.dbconsole.*;

/**
 * Reads a file and attempts to execute the contents as sql commands.
 *
 * @version   $Revision: 18 $
 */
public class FileInputCommand extends Command {
    /**
     * Description of the Method
     *
     * @return   Description of the Returned Value
     */
    public String execute() {
        return execute(null);
    }

    /**
     * Description of the Method
     *
     * @param data
     * @return      Description of the Returned Value
     */
    public String execute(Object data) {
        if (data == null)
            return Bundle.BUNDLE.getString("messagePrompt") + " " + Bundle.BUNDLE.getString("error") + " No file.";

        // data should be a string with the command followed by a file name
        String command = data.toString();
        int index = command.indexOf(" ");
        if (index == -1)
            return Bundle.BUNDLE.getString("messagePrompt") + " " + Bundle.BUNDLE.getString("error") + " No file.";

        InputStream is = null;
        try {
            String filename = command.substring(index + 1);
            File f = new File(filename);
            if (!f.exists())
                return Bundle.BUNDLE.getString("messagePrompt") + " " + Bundle.BUNDLE.getString("error") + " File not found: " + filename;
            
            is = new FileInputStream(f){
                public void close() throws IOException {
                    super.close();
                    DbConsole.getInstance().setEcho(false);
                }
            };
            DbConsole.getInstance().setEcho(true);
            DbConsole.getInstance().setIn(is);
        }
        catch (Exception e) {
            try {
                if (is != null)
                    is.close();
            }
            catch(Exception ignored) {  // NOPMD
            }
        }
        return null;
    }
    
    public boolean showSpinner() {
        return false;
    }
}

