/*
Copyright (c) Dale Anson, 2004

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.   
   3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package ise.dbconsole.command;

import ise.dbconsole.*;


import java.io.*;

/**
 * Attaches a TeeWriter to DbConsole to redirect output to a file as well as
 * to the screen.
 *
 * @author Dale Anson, Sep 2004
 * @version   $Revision: 7 $
 */
public class FileOutputCommand extends Command {

    private PrintStream left = null;
    private PrintStream std_out = null;
    private OutputStream tee = null;

    /** Closes the file output */
    public String execute() {
        try {
            if (left != null)
                left.close();
        }
        catch (Exception e) {
            e.printStackTrace();
        }
        DbConsole.getInstance().resetOut();
        return null;
    }

    /**
     * Attaches a TeeWriter to DbConsole. Filename to write to must be part of
     * the data. File is appended to.
     *
     * @param data Command is: \o [o] filename where [o] is optional 'overwrite'
     * flag. Anything other than 'o' means append.
     *
     */
    public String execute(Object data) {
        if (data == null)
            return null;
        
        // \o [o] filename
        String[] commands = data.toString().split(" ");
        
        String filename;
        String append_mode;
        
        switch(commands.length) {
            case 1:
                return "No filename.";
            case 2:
                append_mode = "a";
                filename = commands[1];
                break;
            case 3:
                append_mode = commands[1];
                filename = commands[2];
                break;
            default:
                return Bundle.BUNDLE.getString("invalidCommand");
        }
        
        // 'o' is overwrite, anything else is append
        boolean append = !append_mode.equalsIgnoreCase("o");
        
        try {
            File f = new File(filename);
            FileOutputStream fos = new FileOutputStream(f, append);
            left = new PrintStream(fos);
            std_out = DbConsole.getInstance().getOut();
            std_out.println(Bundle.BUNDLE.getString("writingTo") + ": " + f.getAbsolutePath());
            tee = new TeeOutputStream(left, std_out);
            DbConsole.getInstance().setOut(new PrintStream(tee));
            return null;
        }
        catch (Exception e) {
            e.printStackTrace();
            DbConsole.getInstance().resetOut();
            return null;
        }
    }
}

