/*
Copyright (c) Dale Anson, 2004

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package ise.dbconsole.command;

import java.util.*;

import ise.dbconsole.*;
import ise.library.*;
import ise.library.ascii.*;


/**
 * @author Dale Anson, Sep 2004
 * @version   $Revision: 12 $
 */
public class ShowHistoryCommand extends Command implements Constants {

    /** Description of the Method */
    public String execute() {
        return execute( null );
    }

    /**
     * Show previous queries and offer the user the ability to rerun a query.
     *
     * @param data
     */
    public String execute( Object data ) {
        // get the command history
        Collection list = DbConsole.getInstance().getSavedQueries();
        if ( list.size() == 0 ) {
            return Bundle.BUNDLE.getString( "noQueriesFound" );
        }

        // fetch the user's choice
        ChoiceInput choiceField = new ChoiceInput( list );
        choiceField.setResourceBundle( Bundle.BUNDLE );
        choiceField.setIntro( Bundle.BUNDLE.getString( "selectCommand" ) + ": " );
        Object o = choiceField.getChoice();
        String command = null;
        if ( o != ChoiceInput.USER_CANCELLED ) {
            command = ( String ) o;
            System.out.println( command );
            DbConsole.getInstance().executeCommand( command );
        }
        else if ( o == ChoiceInput.USER_CANCELLED ) {
            // user selected cancel, so just return without doing anything else
        }
        return null;
    }

    public boolean showSpinner() {
        return false;
    }
}
