/*
Copyright (c) Dale Anson, 2004
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
   1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
   3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
package ise.dbconsole.command;

import ise.dbconsole.*;
import ise.dbconsole.exception.*;

/**
 * @author    Dale Anson, Sep 2004
 * @version   $Revision: 7 $
 */
public class ShowRowCommand extends Command {
    /**
     * Sets a default catalog to use in the DAO.
     *
     * @return   a descriptive string
     */
    public String execute() {
        return execute(null);
    }

    /**
     * Sets a default catalog to use in the DAO.
     *
     * @param data  not used
     * @return      a descriptive string
     */
    public String execute(Object data) {
        DbConsoleDAO dao = DbConsole.getInstance().getDAO();
        if (dao == null)
            return null;

        String srow = "1";  // show row 1 if no row is given.
        if (data != null) {
            srow = (String) data;
            if (srow.indexOf(" ") != -1)
                srow = srow.substring(srow.indexOf(" "));
            else
                srow = "1";
        }

        try {
            int row = srow == null ? 1 : Integer.parseInt(srow.trim());
            return dao.getRow(row);
        }
        catch (NumberFormatException nfe) {
            System.out.println(Bundle.BUNDLE.getString("invalidNumber") + ": " + srow);
        }
        catch (RowIndexOutOfBoundsException roob) {
            System.out.println(Bundle.BUNDLE.getString("invalidRow") + ": " + srow);
        }
        return null;
    }

    
    public boolean showSpinner() {
        return false;
    }
}

