/*
Copyright (c) Dale Anson, 2004
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
   1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
   3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
package ise.dbconsole.command;

import ise.dbconsole.*;

/**
 * @author    Dale Anson, Sep 2004
 * @version   $Revision: 7 $
 */
public class UseColorCommand extends Command implements Constants {
    /**
     * Toggles colored output.
     *
     * @return   a descriptive string
     */
    public String execute() {
        return execute(null);
    }

    /**
     * Toggles colored output or changes color.
     *
     * @param data  not used
     * @return      a descriptive string
     */
    public String execute(Object data) {
        if (data != null) {
            String color = null;
            String[] args = data.toString().split(" ");
            if (args.length > 1) {
                System.setProperty(COLOR, args[1]);
                DbConsoleUtil.setColor(args[1]);
                System.setProperty(SHOW_COLOR, YES);
                DbConsoleUtil.setShowColor(true);
                return Bundle.BUNDLE.getString("colorMode") + " " + args[1] + ".";
            }
        }
        String on = System.getProperty(SHOW_COLOR);
        System.setProperty(SHOW_COLOR, on == null || on.equals(NO) ? YES : NO);
        DbConsoleUtil.setShowColor(on == null || on.equals(NO));
        on = System.getProperty(SHOW_COLOR);
        return Bundle.BUNDLE.getString("colorMode") + " " +
                (on.equals(YES) ? Bundle.BUNDLE.getString("on") : Bundle.BUNDLE.getString("off")) +
                ".";
    }

    /**
     * Description of the Method
     *
     * @return   Description of the Returned Value
     */
    public boolean showSpinner() {
        return false;
    }
    
    
}

