/*
Copyright (c) Dale Anson, 2004
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
   1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
   3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
package ise.dbconsole.to;

import ise.library.*;

/**
 * Transfer object for a User, holds username and password.
 *
 * @version   $Revision: 7 $
 */
public class User implements Comparable {
    private String username;
    private String password;

    /** Constructor for User  */
    public User() {
    }

    /**
     * Constructor for User
     *
     * @param username
     * @param password
     */
    public User(String username, String password) {
        this.username = username;
        this.password = password;
    }

    /**
     * Just the username.
     *
     * @return   just the username
     */
    public String toString() {
        return username;
    }
    
    public int compareTo(Object o) {
        if (o == null)
            return -1;
        if (!(o instanceof User))
            return -1;
        return username.compareTo(((User)o).getUsername());   
    }

    /**
     * Sets the username 
     *
     * @param username  The new username value
     */
    public void setUsername(String username) {
        this.username = username;
    }

    /**
     * Gets the username 
     *
     * @return   The username value
     */
    public String getUsername() {
        return username;
    }

    /**
     * Set the password for this user, this is the encrypted password.
     * @param password  encrypted password
     */
    public void setPassword(String password) {
        this.password = password;
    }

    /**
     * Get the encrypted password
     * @return   encrypted password
     */
    public String getPassword() {
        return password;
    }

    /**
     * @return                              decrypted password
     * @exception PasswordHandlerException  Description of Exception
     */
    public String getPlainPassword() throws PasswordHandlerException {
        PasswordHandler ph = new PasswordHandler();
        return ph.decrypt(password);
    }

}

