package ise.library;

import java.util.*;

/**
 * Monitors memory usage in the virtual machine.  Sends alerts to observers
 * when the memory usage reaches a specified percentage.
 * @author Dale Anson
 */
public class MemoryMonitor extends Observable {

    private List observers = new ArrayList();
    private int warnAtPercent = 0;
    private int currentPercent = 0;

    private boolean canRun = false;
    private boolean isRunning = false;

    public MemoryMonitor( int percent ) {
        warnAtPercent = percent;
    }
    
    public void stop() {
        canRun = false;   
    }

    public void addObserver( Observer o ) {
        observers.add( o );
        canRun = observers.size() > 0;
        if ( canRun && !isRunning ) {
            monitor.start();
        }
    }

    public void removeObserver( Observer o ) {
        observers.remove(o);
        canRun = observers.size() > 0;
        if (!canRun && isRunning) {
            monitor.interrupt();
        }
    }

    public void notifyObservers() {
        Integer current_percent = new Integer( currentPercent );
        for ( Iterator it = observers.iterator(); it.hasNext(); ) {
            Observer o = ( Observer ) it.next();
            o.update( this, current_percent );
        }
    }

    Thread monitor = new Thread() {
                public void run() {
                    try {
                        isRunning = true;
                        while ( canRun ) {
                            if ( observers.size() > 0 ) {
                                Runtime runtime = Runtime.getRuntime();
                                long free_memory = runtime.freeMemory();
                                long max_memory = runtime.maxMemory();
                                currentPercent = ( int ) ( ( free_memory / max_memory ) * 100 );
                                if ( currentPercent >= warnAtPercent )
                                    notifyObservers();
                            }
                            sleep( 5000 );
                        }
                    }
                    catch ( InterruptedException e ) {
                        isRunning = false;
                    }
                }
            };




}
